@@ -46,7 +46,7 @@ static void getProcessInformation(pid_t pid, FFstrbuf* processName, FFstrbuf* ex
     ssize_t length = readlink(filePath, exePath->chars, exePath->allocated - 1);
     if (length > 0) // doesn't contain trailing NUL
     {
-        exePath->chars[length + 1] = '\0';
+        exePath->chars[length] = '\0';
         exePath->length = (uint32_t) length;
     }
 
@@ -243,6 +243,7 @@ static pid_t getShellInfo(FFShellResult* result, pid_t pid)
                 ffStrEquals(name, "perf")                ||
                 ffStrEquals(name, "guake-wrapped")       ||
                 ffStrEquals(name, "time")                ||
+                ffStrEquals(name, "hyfetch")             || //when hyfetch uses fastfetch as backend
                 ffStrContainsIgnCase(name, "debug")      ||
                 ffStrContainsIgnCase(name, "not-found")  ||
                 ffStrEndsWith(name, ".sh")
@@ -306,10 +307,19 @@ static pid_t getTerminalInfo(FFTerminalResult* result, pid_t pid)
 
         #ifdef __APPLE__
         // https://github.com/fastfetch-cli/fastfetch/discussions/501
-        if (ffStrEndsWith(name, " (figterm)") || ffStrEndsWith(name, " (cwterm)"))
+        const char* pLeft = strstr(name, " (");
+        if (pLeft)
         {
-            if (__builtin_expect(getProcessNameAndPpid(ppid, name, &ppid, NULL) != NULL, false))
-                return 0;
+            pLeft += 2;
+            const char* pRight = strstr(pLeft, "term)");
+            if (pRight && pRight[5] == '\0')
+            {
+                for (; pLeft < pRight; ++pLeft)
+                    if (*pLeft < 'a' || *pLeft > 'z')
+                        break;
+                if (pLeft == pRight && getProcessNameAndPpid(ppid, name, &ppid, NULL) != NULL)
+                    return 0;
+            }
         }
         #endif
 
@@ -482,14 +492,12 @@ static void setShellInfoDetails(FFShellResult* result)
 
 static void setTerminalInfoDetails(FFTerminalResult* result)
 {
-    if(result->exeName[0] == '.' && ffStrEndsWith(result->exeName, "-wrapped"))
+    if(ffStrbufStartsWithC(&result->processName, '.') && ffStrbufEndsWithS(&result->processName, "-wrapped"))
     {
         // For NixOS. Ref: #510 and https://github.com/NixOS/nixpkgs/pull/249428
         // We use processName when detecting version and font, overriding it for simplification
-        ffStrbufSetNS(
-            &result->processName,
-            (uint32_t) (strlen(result->exeName) - strlen(".-wrapped")),
-            result->exeName + 1);
+        ffStrbufSubstrBefore(&result->processName, result->processName.length - (uint32_t) strlen("-wrapped"));
+        ffStrbufSubstrAfter(&result->processName, 0);
     }
 
     if(ffStrbufEqualS(&result->processName, "wezterm-gui"))
@@ -520,6 +528,11 @@ static void setTerminalInfoDetails(FFTerminalResult* result)
 
     else if(ffStrbufEqualS(&result->processName, "iTerm.app") || ffStrbufStartsWithS(&result->processName, "iTermServer-"))
         ffStrbufInitStatic(&result->prettyName, "iTerm");
+    else if(ffStrbufEndsWithS(&result->exePath, "Terminal.app/Contents/MacOS/Terminal"))
+    {
+        ffStrbufSetStatic(&result->processName, "Apple_Terminal"); // for terminal font detection
+        ffStrbufInitStatic(&result->prettyName, "Apple Terminal");
+    }
     else if(ffStrbufEqualS(&result->processName, "Apple_Terminal"))
         ffStrbufInitStatic(&result->prettyName, "Apple Terminal");
     else if(ffStrbufEqualS(&result->processName, "WarpTerminal"))
