@@ -21,6 +21,7 @@ typedef struct FFOptionsDisplay
     //If one of those is empty, ffLogoPrint will set them
     FFstrbuf colorKeys;
     FFstrbuf colorTitle;
+    FFstrbuf colorOutput;
 
     bool brightColor;
 
@@ -34,7 +35,7 @@ typedef struct FFOptionsDisplay
     FFBinaryPrefixType binaryPrefixType;
     uint8_t sizeNdigits;
     uint8_t sizeMaxPrefix;
-    FFTemperatureUnit temperatureUnit;
+    FFTemperatureUnit tempUnit;
     uint8_t tempNdigits;
     FFstrbuf tempColorGreen;
     FFstrbuf tempColorYellow;
